package com.vrtcal.sampleapp;

import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import android.Manifest;
import android.app.Activity;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.view.WindowManager;
import android.widget.Toast;

import com.vrtcal.sdk.*;


public class MainActivity extends Activity {
    private VrtcalBanner banner = null;
    private VrtcalInterstitial interstitial = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN,
                WindowManager.LayoutParams.FLAG_FULLSCREEN);
        setContentView(R.layout.activity_main);

        // Request location permission (this is from Google Developers page)
        if (ContextCompat.checkSelfPermission(this,
                Manifest.permission.ACCESS_FINE_LOCATION)
                != PackageManager.PERMISSION_GRANTED) {
            // Permission is not granted
            // Should we show an explanation?
            if (ActivityCompat.shouldShowRequestPermissionRationale(this,
                    Manifest.permission.ACCESS_FINE_LOCATION)) {
                // Show an explanation to the user *asynchronously* -- don't block
                // this thread waiting for the user's response! After the user
                // sees the explanation, try again to request the permission.
            } else {
                // No explanation needed; request the permission
                ActivityCompat.requestPermissions(this,
                        new String[]{Manifest.permission.ACCESS_FINE_LOCATION},
                        123);

                // MY_PERMISSIONS_REQUEST_READ_CONTACTS is an
                // app-defined int constant. The callback method gets the
                // result of the request.
            }
        } else {
            // Permission has already been granted
        }

        // Initialize VRTCAL SDK
        VrtcalSdk.init(this, 11073, new VrtcalSdkListener() {
            @Override
            public void onSdkInitialized() {
                showMessage("SDK initialized");
            }

            @Override
            public void onSdkFailedToInitialize(Reason reason) {
                showMessage("SDK failed to initialize: " + reason);
            }
        });
    }

    public void onLoadBannerClicked(View view) {
        banner = new VrtcalBanner(this);

        banner.setAdListener(new VrtcalBannerListener() {
            @Override
            public void onAdLoaded(final VrtcalBanner banner) {
                showMessage("Banner loaded");

                // SDK event callbacks are called from background thread.  To perform a UI
                // operation such as adding a view to UI, do it in main thread.
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        ViewGroup bannerContainer = findViewById(R.id.bannerContainer);

                        // Verify banner view has not already been added, since onAdLoaded()
                        // is called on every successful banner refresh.
                        if (bannerContainer.indexOfChild(banner) == -1) {
                            bannerContainer.addView(banner);
                        }
                    }
                });
            }

            @Override
            public void onAdFailed(VrtcalBanner banner, Reason reason) {
                showMessage("Banner failed: " + reason);
            }

            @Override
            public void onAdClicked(VrtcalBanner banner) {
                showMessage("Banner clicked");
            }

            @Override
            public void onAdExpanded(VrtcalBanner banner) {
                showMessage("Banner expanded");
            }

            @Override
            public void onAdCollapsed(VrtcalBanner banner) {
                showMessage("Banner collapsed");
            }

            @Override
            public void onAdVideoStarted(VrtcalBanner vrtcalBanner) {
                showMessage("Banner video started");
            }

            @Override
            public void onAdVideoCompleted(VrtcalBanner vrtcalBanner) {
                showMessage("Banner video completed");
            }
        });

        banner.loadAd(10005);
    }

    public void onDestroyBannerClicked(View view) {
        ViewGroup bannerContainer = findViewById(R.id.bannerContainer);
        bannerContainer.removeView(banner);
        if (banner != null) {
            banner.destroy();
            banner = null;
        }
    }

    public void onLoadDisplayInterstitialClicked(View view) {
        interstitial = new VrtcalInterstitial(this);

        interstitial.setAdListener(new VrtcalInterstitialListener() {
            @Override
            public void onAdLoaded(VrtcalInterstitial interstitial) {
                showMessage("Interstitial loaded");
            }

            @Override
            public void onAdFailedToLoad(VrtcalInterstitial interstitial, Reason reason) {
                showMessage("Interstitial failed to load: " + reason);
            }

            @Override
            public void onAdShown(VrtcalInterstitial interstitial) {
                showMessage("Interstitial shown");
            }

            @Override
            public void onAdFailedToShow(VrtcalInterstitial interstitial, Reason reason) {
                showMessage("Interstitial failed to show: " + reason);
            }

            @Override
            public void onAdClicked(VrtcalInterstitial interstitial) {
                showMessage("Interstitial clicked");
            }

            @Override
            public void onAdDismissed(VrtcalInterstitial interstitial) {
                showMessage("Interstitial dismissed");
            }
        });

        interstitial.loadAd(10009);
    }

    public void onShowInterstitialClicked(View view) {
        if (interstitial != null) {
            interstitial.showAd();
        }
    }

    private void showMessage(final String message) {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(MainActivity.this, message, Toast.LENGTH_LONG).show();
            }
        });
        Log.i("MainActivity", message);
    }
}
